#!/bin/bash

ss7box_dir=../ss7box
reldir=release
HOME=$PWD

#includes RELEASE_NUM and SMG_CFG_PY_FILE 
source release.include

sangoma_isup_dirname=xygisup
sangoma_isup_dir=$HOME/../$sangoma_isup_dirname
sangoma_xmtp2_dir=$HOME/../xmtp2km

svn_rev=`svn info | grep Revision | cut -d' ' -f2`
svn_rev=${svn_rev/ /}

release_num="$RELEASE_NUM.$svn_rev"
prod_name="smgss7"

clear  
echo
echo "==================================================================="
echo "SMGSS7 Release Build"
echo
echo "Release: $prod_name | Version: $release_num | SMGCfg: $SMG_CFG_PY_FILE ?"               
echo
echo "SVN Rev: $svn_rev"
echo "Note: Make sure to run svn update so that 'svn info'" 
echo "      command displays correct svn rev number"
echo 
echo "(y/n) ?"
echo "==================================================================="
read answer
if [ "$answer" != "y" ]; then
	echo
	echo "Aborting release build"
  	exit 1
fi


function debug
{
	ls -l $sangoma_isup_dir/smgcfg*
	echo "press Enter to continue; ctl-c to quit"
	read $blah
}

function copy_file
{
	echo "copy $1 to $2"
	if [ -z $1 ] || [ ! -e $1 ] ; then
		echo "missing file: $1"
		exit 1
	fi
	if [ ! -d $2 ] ; then
		echo "missing directory: $2"
		if [ -e $2 ] ; then
			echo "overwriting existing file $2"
		else
			exit 1
		fi
	fi
	if ! cp $1 $2 ; then
		echo "copy failed"
		exit 1
	fi
	
	return 0
}

function build_xmtp2
{

	homedir=$PWD
	cd $sangoma_xmtp2_dir
	make clean
	make
	make tarball
	cp sangoma_xmtp2km.tgz $HOME
	cd $homedir
}

function build_release
{
	homedir=$PWD
	cd $sangoma_isup_dir
	../auth/build.py -s $1
	make clean 
	make deps WANPIPE_VERSION="$wanpipe_rel"
	make WANPIPE_VERSION="$wanpipe_rel"
	cd $ss7box_dir
	make clean deps all
	cd $homedir	
}

function copy_release_components
{
	echo "copying release components"
	pwd
	rm -f ./notes/*
	rm -f ./new/*
	rm -f *.conf
	
	copy_file $sangoma_isup_dir/$SMG_CFG_PY_FILE .
	
#	copy_file $ss7box_dir/ss7box.conf .
#	copy_file $ss7box_dir/ss7box.conf ./new
	
	copy_file $ss7box_dir/cli/ss7box_cli .
	copy_file $ss7box_dir/cli/ss7box_cli ./new
	./ss7box_cli --ver
	copy_file $ss7box_dir/cli/ss7box_cli.conf .
	copy_file $ss7box_dir/cli/ss7box_cli.conf ./new
	
	copy_file $sangoma_isup_dir/sangoma_isupd .
	copy_file $sangoma_isup_dir/sangoma_isupd ./new
	eval "./sangoma_isupd --ver"
#	copy_file $sangoma_isup_dir/sangoma_isup.conf .
#	copy_file $sangoma_isup_dir/sangoma_isup.conf ./new
#	copy_file $sangoma_isup_dir/tg*.conf ./new
	copy_file $sangoma_isup_dir/RELEASE_NOTES.sangoma_isup.txt ./notes
	
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli .
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli ./new
	eval "./sangoma_isup_cli --ver"
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli.conf .
	copy_file $sangoma_isup_dir/cli/sangoma_isup_cli.conf ./new
	copy_file $sangoma_isup_dir/cli/RELEASE_NOTES.sangoma_isup_cli.txt ./notes/
	
	copy_file $sangoma_isup_dir/cdr/cdr_logger .
	copy_file $sangoma_isup_dir/cdr/cdr_logger ./new
	eval "./cdr_logger --ver"
	copy_file $sangoma_isup_dir/cdr/cdr_logger.conf .
	copy_file $sangoma_isup_dir/cdr/cdr_logger.conf ./new
	copy_file $sangoma_isup_dir/cdr/RELEASE_NOTES.sangoma_isup_cdr.txt ./notes/
	
	rm *~
}

function tarball
{
	echo tarball
	local release_dir=$prod_name-$1-$release_num
#  	if [ -z $1 ] ; then
# 		echo "Missing revision string."
# 		exit 1
# 	fi
	cd ..
	cp -rf $reldir/ $release_dir/

	cd  $release_dir
    eval "cat smginstall | sed -e s/^REL=.*/REL=$wanpipe_rel/ > temp.$$" 
	cp temp.$$ smginstall
	chmod 755 smginstall
	rm temp.$$ 
	cd ..

	find $release_dir -name '*.svn' | xargs rm -rf
	ls -l $release_dir/
 	tar czvf $release_dir.tgz $release_dir/
	pwd
	cd $reldir/
	pwd
}

# main

wanpipe_release=${1:-invalid_wanpipe_release}

if [ ! -e $wanpipe_release ]; then
  	echo "Error: wanpipe_release: \"$wanpipe_release\" not found!"
	exit 1
fi

\rm -rf $sangoma_isup_dir/driver/*
\cp -f $wanpipe_release .
cd $sangoma_isup_dir/driver/
eval "tar xfz $wanpipe_release"
if [ $? -ne 0 ]; then
	echo "Error: Failed to untar $wanpipe_release"
	exit 1
fi

wanpipe_rel=${wanpipe_release/*\//}
wanpipe_rel=${wanpipe_rel/wanpipe-/}
wanpipe_rel=${wanpipe_rel/.tgz/}

if [ "$wanpipe_rel" = "" ]; then
  	echo "Invalid Wanpipe Release $wanpipe_rel"
fi
echo "wanpipe_rel = $wanpipe_rel"

cd $HOME

rm -f $sangoma_isup_dir/site_notices/*
datestring=$(date +%F)
datestring=${datestring/-/}
datestring=${datestring/-/}
site_notice_itu=$sangoma_isup_dirname/site_notices/site-m3ua-itu.txt
site_notice_ansi=$sangoma_isup_dirname/site_notices/site-m3ua-ansi.txt

find . -name '$prod_name*ANSI*' | xargs rm -rf 
find . -name '$prod_name*ITU*' | xargs rm -rf 
find . -name 'smg*ANSI*' | xargs rm -rf 
find . -name 'smg*ITU*' | xargs rm -rf 
find . -name 'smgss7*ansi*' | xargs rm -rf 
find . -name 'smgss7*itu*' | xargs rm -rf 

build_xmtp2	

# make ANSI release
build_release "m3ua-ansi"
debug
copy_release_components
debug
tarball "ansi" $datestring 
debug

# make ITU release
build_release "m3ua-itu"
debug
copy_release_components
debug
tarball "itu" $datestring
debug

cd ..
ls -l $site_notice_itu
echo
cat $site_notice_itu
echo
ls -l $site_notice_ansi
echo
cat $site_notice_ansi
echo


mv  $prod_name-"itu"-$release_num $reldir/
mv  $prod_name-"itu"-$release_num".tgz" $reldir/
mv  $prod_name-"ansi"-$release_num $reldir/
mv  $prod_name-"ansi"-$release_num".tgz" $reldir/

cd $reldir
ls -l $prod_name*.tgz
